# Contributing to Sparkler

Thanks for your interest in Sparkler. Our goal is to develop an efficient, scalable web crawler to help you retrieve the resources from web with ease of use.

## Getting Started

Sparkler's [open issues are here](https://github.com/USCDataScience/sparkler/issues). In time, we'll tag issues that would make a good first pull request for new contributors. An easy way to get started helping the project is to *file an issue*. You can do that on the Sparkler issues page by clicking on the green button at the right. Issues can include bugs to fix, features to add, or documentation that looks outdated.

For some tips on contributing to open source, this [post is helpful](http://blog.smartbear.com/programming/14-ways-to-contribute-to-open-source-without-being-a-programming-genius-or-a-rock-star/).


## Contributions

Sparkler team welcomes contributions from everyone.

Contributions to Sparkler should be made in the form of GitHub pull requests. Each pull request will be reviewed by a core contributor (someone with permission to land patches) and either landed in the main tree or given feedback for changes that would be required.

## Pull Request Checklist

- If an issue already exists in [issues page](https://github.com/USCDataScience/sparkler/issues) 
  to describe the change you are bringing into, great, remember the $ISSUENUM.
  Otherwise, create an issue and get its $ISSUENUM.

- Branch from the master branch (ideally, with branch name 'SPKLR-$ISSUENUM') and, if needed, rebase to the current master
  branch before submitting your pull request. If it doesn't merge cleanly with
  master you may be asked to rebase your changes.

- Commits should be as small as possible, while ensuring that each commit is
  correct independently (i.e., each commit should compile and pass tests).

- Commit messages shall start with "SPKLR-$ISSUENUM: ...."

- All the additional libraries, plugins you bring into the Sparkler have a license permissible to redistribute under Apache License 2.0. Ask us incase you are doubtful about a specific library.

- If your patch is not getting reviewed or you need a specific person to review it, you can @-reply a reviewer asking for a review in the pull request or a comment.

- Add tests relevant to the fixed bug or new feature.

- **Code style:**

   *Java style:* The project includes a code format file named  `eclipse-codeformat.xml` in the root directory.
 Depending on the IDE you use, please configure the code style rules from this XML file.

   *Scala Style:* The project also includes a code format file named `scalastyle_config.xml` in the root directory.
 Depending on the IDE you use, please configure the code style rules from this XML file. Visit http://www.scalastyle.org/
 for more details

- **License Header:**

  All source files should include Apache License 2.0 header. Refer existing source files (.java, .scala or .xml) for an example.

## Conduct

We follow the [The Apache Software Foundation's Code of Conduct](https://www.apache.org/foundation/policies/conduct).

All code in this repository is under the Apache Software Foundation License, 2.0.
